@@ -73,7 +73,7 @@ class Dashboard:
       :py:class:`werkzeug.middleware.profiler.ProfilerMiddleware` if
       :code:`True` (default: :code:`False`).
     - **PER_PAGE**: Maximum number of jobs to show per page
-      (default: 25).
+      (default: 24).
     - **CARDS_PER_ROW**: Cards to show per row in the desktop view. Must be a
       factor of 12 (default: 3).
     - **ACCESS_TOKEN**: The access token required to login to the dashboard.
@@ -116,7 +116,7 @@ class Dashboard:
         self.config.setdefault("DEBUG", False)
         self.config.setdefault("PORT", 8888)
         self.config.setdefault("PAGINATION", True)
-        self.config.setdefault("PER_PAGE", 25)
+        self.config.setdefault("PER_PAGE", 24)
         self.config.setdefault("CARDS_PER_ROW", 3)
         if 12 % self.config["CARDS_PER_ROW"] != 0:
             raise ValueError(
@@ -178,7 +178,7 @@ class Dashboard:
         self._modules_by_context = modules_by_context
 
     def _create_app(self, config={}):
-        """Creates a Flask application.
+        """Create a Flask application.
 
         :param config: Dictionary of configuration parameters.
         """
@@ -224,7 +224,6 @@ class Dashboard:
 
     def _create_assets(self):
         """Add assets for inclusion in the dashboard HTML."""
-
         assets = Environment(self.app)
         # jQuery is served as a standalone file
         jquery = Bundle("js/jquery-*.min.js", output="gen/jquery.min.js")
@@ -257,7 +256,7 @@ class Dashboard:
         self._module_assets.append(asset)
 
     def run(self, *args, **kwargs):
-        """Runs the dashboard webserver.
+        """Run the dashboard webserver.
 
         Use :py:meth:`~.main` instead of this method for the command-line
         interface. Arguments to this function are passed directly to
@@ -294,7 +293,7 @@ class Dashboard:
         (but verbose) form of the job state point, based on the project schema.
 
         :param job: The job being titled.
-        :type job: :py:class:`signac.contrib.job.Job`
+        :type job: :py:class:`signac.job.Job`
         :returns: Title to be displayed.
         :rtype: str
         """
@@ -332,7 +331,7 @@ class Dashboard:
         minimal unique substring of the job id.
 
         :param job: The job being subtitled.
-        :type job: :py:class:`signac.contrib.job.Job`
+        :type job: :py:class:`signac.job.Job`
         :returns: Subtitle to be displayed.
         :rtype: str
         """
@@ -347,7 +346,7 @@ class Dashboard:
         strings or tuples of properties that should be used to sort.
 
         :param job: The job being sorted.
-        :type job: :py:class:`signac.contrib.job.Job`
+        :type job: :py:class:`signac.job.Job`
         :returns: Key for sorting.
         :rtype: any comparable type
         """
@@ -377,7 +376,7 @@ class Dashboard:
                     f = json.loads(query)
                 except json.JSONDecodeError:
                     query = shlex.split(query)
-                    f = signac.contrib.filterparse.parse_filter_arg(query)
+                    f = signac.filterparse.parse_filter_arg(query)
                     flash(f"Search string interpreted as '{json.dumps(f)}'.")
             jobs = self.project.find_jobs(filter=f)
             return sorted(jobs, key=lambda job: self.job_sorter(job))
@@ -479,7 +478,7 @@ class Dashboard:
     def add_url(
         self, import_name, url_rules=[], import_file="signac_dashboard", **kwargs
     ):
-        """Add a route to the dashboard.
+        r"""Add a route to the dashboard.
 
         This method allows custom view functions to be triggered for specified
         routes. These view functions are imported lazily, when their route
@@ -533,7 +532,7 @@ class Dashboard:
             )
 
     def _register_routes(self):
-        """Registers routes with the Flask application.
+        """Register routes with the Flask application.
 
         This method configures context processors, templates, and sets up
         routes for a basic Dashboard instance. Additionally, routes declared by
@@ -640,7 +639,7 @@ class Dashboard:
         return self.app(environ, start_response)
 
     def main(self, command_args=None):
-        """Runs the command line interface.
+        """Run the command line interface.
 
         Call this function to use signac-dashboard from its command line
         interface. For example, save this script as :code:`dashboard.py`:
@@ -665,7 +664,6 @@ class Dashboard:
             ``["--debug", "--port", "8889"]`` (default: None).
         :type command_args: list
         """
-
         if command_args is not None and len(command_args) == 0:
             command_args = None
 
