@@ -15,11 +15,13 @@ class ImageViewer(Module):
 
     The ImageViewer module can display images in any format that works with a standard
     ``<img>`` tag. The module defaults to showing all images of PNG, JPG, GIF, and SVG
-    types in the job or project root directory. A filename or glob can be
+    types in the job or project directory. A filename or glob can be
     defined to select specific filenames. Each matching file yields a card.
 
     Multiple ImageViewer modules can be defined with different filenames or
-    globs to enable/disable cards for each image or image group. Examples:
+    globs to enable/disable cards for each image or image group.
+
+    :Example:
 
     .. code-block:: python
 
@@ -27,14 +29,16 @@ class ImageViewer(Module):
         img_mod = ImageViewer()  # Show all PNG/JPG/GIF/SVG images
         img_mod = ImageViewer(name='Bond Order Diagram', img_globs=['bod.png'])
         img_mod = ImageViewer(context="ProjectContext",
-                              img_globs=['/gallery/*.png'])  # search subdirectory of project root
+                              img_globs=['/gallery/*.png'])  # search subdirectory of project path
 
     :param context: Supports :code:`'JobContext'` and :code:`'ProjectContext'`.
     :type context: str
     :param img_globs: A list of glob expressions or exact filenames,
-        relative to the job or project root directory, to be
-        displayed (default: :code:`['*.png', '*.jpg', '*.gif', '*.svg']`).
+        relative to the job or project directory, to be displayed
+        (default: :code:`['*.png', '*.jpg', '*.gif', '*.svg']`).
     :type img_globs: list
+    :type sort_key: callable
+    :param sort_key: Key to sort the image files, passed internally to :code:`sorted`.
 
     """
 
@@ -46,9 +50,9 @@ class ImageViewer(Module):
         context="JobContext",
         template="cards/image_viewer.html",
         img_globs=("*.png", "*.jpg", "*.gif", "*.svg"),
+        sort_key=None,
         **kwargs,
     ):
-
         super().__init__(
             name=name,
             context=context,
@@ -56,6 +60,7 @@ class ImageViewer(Module):
             **kwargs,
         )
         self.img_globs = img_globs
+        self.sort_key = sort_key
 
     def get_cards(self, job_or_project):
         if self.context == "JobContext":
@@ -80,5 +85,6 @@ class ImageViewer(Module):
             glob.iglob(job_or_project.fn(image_glob)) for image_glob in self.img_globs
         ]
         image_files = itertools.chain(*image_globs)
+        image_files = sorted(image_files, key=self.sort_key)
         for filepath in image_files:
             yield make_card(os.path.relpath(filepath, job_or_project.fn("")))
