@@ -9,7 +9,7 @@ from werkzeug.utils import cached_property, import_string
 
 def simplified_keys(project):
     sps = list(project.find_statepoints())
-    varied_keys = list()
+    varied_keys = []
     for key in sps[0]:
         same_for_all = True  # This key has the same value for all statepoints
         for sp in sps:
